==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Desired outbound IP Prefix resources for the cluster load balancer.
 * @property publicIPPrefixes A list of public IP prefix resources.
 */
public data class ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs(
    public val publicIPPrefixes: Output<List<ResourceReferenceArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs.builder()
            .publicIPPrefixes(
                publicIPPrefixes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs].
 */
@PulumiTagMarker
public class ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgsBuilder internal constructor() {
    private var publicIPPrefixes: Output<List<ResourceReferenceArgs>>? = null

    /**
     * @param value A list of public IP prefix resources.
     */
    @JvmName("rqcfyujdwauvmfnt")
    public suspend fun publicIPPrefixes(`value`: Output<List<ResourceReferenceArgs>>) {
        this.publicIPPrefixes = value
    }

    @JvmName("utbqloslorbuxerp")
    public suspend fun publicIPPrefixes(vararg values: Output<ResourceReferenceArgs>) {
        this.publicIPPrefixes = Output.all(values.asList())
    }

    /**
     * @param values A list of public IP prefix resources.
     */
    @JvmName("oxxhbcbieolcaqau")
    public suspend fun publicIPPrefixes(values: List<Output<ResourceReferenceArgs>>) {
        this.publicIPPrefixes = Output.all(values)
    }

    /**
     * @param value A list of public IP prefix resources.
     */
    @JvmName("xbeaoisfwfpwnkdg")
    public suspend fun publicIPPrefixes(`value`: List<ResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPPrefixes = mapped
    }

    /**
     * @param argument A list of public IP prefix resources.
     */
    @JvmName("dmrvddgrvnyibyqe")
    public suspend
    fun publicIPPrefixes(argument: List<suspend ResourceReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.publicIPPrefixes = mapped
    }

    /**
     * @param argument A list of public IP prefix resources.
     */
    @JvmName("jypsdfivxtaroixk")
    public suspend fun publicIPPrefixes(
        vararg
        argument: suspend ResourceReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.publicIPPrefixes = mapped
    }

    /**
     * @param argument A list of public IP prefix resources.
     */
    @JvmName("urccybnsaqjwhveo")
    public suspend fun publicIPPrefixes(argument: suspend ResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.publicIPPrefixes = mapped
    }

    /**
     * @param values A list of public IP prefix resources.
     */
    @JvmName("ypbobmawqkgekopv")
    public suspend fun publicIPPrefixes(vararg values: ResourceReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicIPPrefixes = mapped
    }

    internal fun build(): ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs =
        ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs(
            publicIPPrefixes = publicIPPrefixes,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Desired outbound IP Prefix resources for the cluster load balancer.
 * @property publicIPPrefixes A list of public IP prefix resources.
 */
public data class ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs(
    public val publicIPPrefixes: Output<List<ResourceReferenceArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs.builder()
            .publicIPPrefixes(
                publicIPPrefixes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs].
 */
@PulumiTagMarker
public class ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgsBuilder internal constructor() {
    private var publicIPPrefixes: Output<List<ResourceReferenceArgs>>? = null

    /**
     * @param value A list of public IP prefix resources.
     */
    @JvmName("jqdtpegfngssimjl")
    public suspend fun publicIPPrefixes(`value`: Output<List<ResourceReferenceArgs>>) {
        this.publicIPPrefixes = value
    }

    @JvmName("mftivfivnmynjuoc")
    public suspend fun publicIPPrefixes(vararg values: Output<ResourceReferenceArgs>) {
        this.publicIPPrefixes = Output.all(values.asList())
    }

    /**
     * @param values A list of public IP prefix resources.
     */
    @JvmName("mlqhvvrnhsxbrbqn")
    public suspend fun publicIPPrefixes(values: List<Output<ResourceReferenceArgs>>) {
        this.publicIPPrefixes = Output.all(values)
    }

    /**
     * @param value A list of public IP prefix resources.
     */
    @JvmName("igtwihfhmicfufva")
    public suspend fun publicIPPrefixes(`value`: List<ResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPPrefixes = mapped
    }

    /**
     * @param argument A list of public IP prefix resources.
     */
    @JvmName("jousrjqiwfftgnsh")
    public suspend
    fun publicIPPrefixes(argument: List<suspend ResourceReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.publicIPPrefixes = mapped
    }

    /**
     * @param argument A list of public IP prefix resources.
     */
    @JvmName("obtyhxgyuxfslscr")
    public suspend fun publicIPPrefixes(
        vararg
        argument: suspend ResourceReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.publicIPPrefixes = mapped
    }

    /**
     * @param argument A list of public IP prefix resources.
     */
    @JvmName("omnavwiahpixxxpi")
    public suspend fun publicIPPrefixes(argument: suspend ResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.publicIPPrefixes = mapped
    }

    /**
     * @param values A list of public IP prefix resources.
     */
    @JvmName("blrtahwsmvajdqtj")
    public suspend fun publicIPPrefixes(vararg values: ResourceReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicIPPrefixes = mapped
    }

    internal fun build(): ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs =
        ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs(
            publicIPPrefixes = publicIPPrefixes,
        )
}
